==> haskell-project-template-0.2.1.0-498-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-4UHwMA2QZAN3Ivkxoefv2s
key:                  project-template-0.2.1.0-4UHwMA2QZAN3Ivkxoefv2s
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  c3e1863847564e51cb498a38477d95b5
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-4UHwMA2QZAN3Ivkxoefv2s
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-9LHYaxMplJVGg4IRiFtzGp
    bytestring-0.11.5.3 conduit-1.3.6.1-9Ano6zkKE8Q3t2Yg7Ibwss
    conduit-extra-1.3.8-B6Eb1ypzIORHRjCExezdNC containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    resourcet-1.2.6-JmCxdoDVdAFAYoX7rfTvi0 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.1.0-499-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-LVWQDFkZmBGGfg1RlugKRt
key:                  project-template-0.2.1.0-LVWQDFkZmBGGfg1RlugKRt
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  3a46cb481110cf21940f4db64134b84f
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-LVWQDFkZmBGGfg1RlugKRt
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-B0w0hfBZVmq3UW6lmjr7G
    bytestring-0.11.5.3 conduit-1.3.6.1-JmvSlylEAqiI8LFhx2lxVp
    conduit-extra-1.3.8-GJ8Ijj1CXjtIz1f8rXkRx2 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    resourcet-1.2.6-6GDX0mNNFVQIZmMacsito5 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
